@@ -39,6 +39,7 @@ QTEST_KDEMAIN_CORE( KUrlTest )
 #include <QtCore/QMap>
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h> // gethostname
 
 //QCOMPARE cannot be used to strictly check for empty or null QString as it treats QString("") == QString()
 #define QSTREMPTY(_str) QVERIFY(!_str.isNull() && _str.isEmpty())
@@ -198,8 +199,17 @@ void KUrlTest::testIsLocalFile()
   KUrl local_file_2("file://www.kde.org/my/file");
   QVERIFY( !local_file_2.isLocalFile() );
 
+  // exactly like in kurl.cpp, getenv("HOSTNAME") can be different...
+  char hostname[ 256 ];
+  hostname[ 0 ] = '\0';
+  if (!gethostname( hostname, 255 ))
+     hostname[sizeof(hostname)-1] = '\0';
+
+  for(char *p = hostname; *p; p++)
+     *p = tolower(*p);
+
   KUrl local_file_3;
-  local_file_3.setHost(getenv("HOSTNAME"));
+  local_file_3.setHost(QString::fromLatin1(hostname));
   local_file_3.setPath("/my/file");
   //qDebug("URL=%s\n", qPrintable( local_file_3.url() ));
   QVERIFY( local_file_3.isLocalFile() );
