@@ -385,7 +385,9 @@ KDirOperator::KDirOperator(const KUrl& _url, QWidget *parent) :
     if (_url.isEmpty()) { // no dir specified -> current dir
         QString strPath = QDir::currentPath();
         strPath.append(QChar('/'));
-        d->currUrl = QUrl::fromLocalFile(strPath);
+        d->currUrl = KUrl();
+        d->currUrl.setProtocol(QLatin1String("file"));
+        d->currUrl.setPath(strPath);
     } else {
         d->currUrl = _url;
         if (d->currUrl.protocol().isEmpty())
@@ -1032,11 +1034,17 @@ void KDirOperator::setUrl(const KUrl& _newurl, bool clearforward)
     KUrl newurl;
 
     if (!_newurl.isValid())
-        newurl = QUrl::fromLocalFile(QDir::homePath());
+        newurl.setPath(QDir::homePath());
     else
         newurl = _newurl;
 
     newurl.adjustPath( KUrl::AddTrailingSlash );
+#ifdef Q_WS_WIN
+    QString pathstr = (newurl.isLocalFile()) ? QDir::fromNativeSeparators(newurl.toLocalFile()) : newurl.path();
+#else
+    QString pathstr = newurl.path();
+#endif
+    newurl.setPath(pathstr);
 
     // already set
     if (newurl.equals(d->currUrl, KUrl::CompareWithoutTrailingSlash))
@@ -1250,7 +1258,8 @@ void KDirOperator::cdUp()
 
 void KDirOperator::home()
 {
-    KUrl u = QUrl::fromLocalFile(QDir::homePath());
+    KUrl u;
+    u.setPath(QDir::homePath());
     setUrl(u, true);
 }
 
