@@ -448,7 +448,7 @@ bool CSSStyleDeclarationImpl::isPropertyImplicit(int propertyID) const
     while ( lstValuesIt.hasNext() ) {
         current = lstValuesIt.next();
         if (current->m_id == propertyID)
-            return current->isImplicit();;
+            return current->isImplicit();
     }
     return false;
 }
@@ -849,10 +849,10 @@ DOM::DOMString CSSStyleDeclarationImpl::cssText() const
         if (positionXProp->value()->isValueList() || positionYProp->value()->isValueList())
             positionValue = getLayeredShortHandValue(properties, 2);
         else
-            positionValue = positionXProp->value()->cssText() + " " + positionYProp->value()->cssText();
+            positionValue = positionXProp->value()->cssText() + DOMString(" ") + positionYProp->value()->cssText();
         result += DOMString("background-position: ") + positionValue
                                                      + DOMString((positionXProp->isImportant() ? " !important" : ""))
-                                                     + "; ";
+                                                     + DOMString("; ");
     } else {
         if (positionXProp)
             result += positionXProp->cssText();
@@ -1264,10 +1264,10 @@ DOM::DOMString CSSPrimitiveValueImpl::cssText() const
         {
             RectImpl* rectVal = getRectValue();
             text = "rect(";
-            text += rectVal->top()->cssText() + " ";
-            text += rectVal->right()->cssText() + " ";
-            text += rectVal->bottom()->cssText() + " ";
-            text += rectVal->left()->cssText() + ")";
+            text += rectVal->top()->cssText() + DOMString(" ");
+            text += rectVal->right()->cssText() + DOMString(" ");
+            text += rectVal->bottom()->cssText() + DOMString(" ");
+            text += rectVal->left()->cssText() + DOMString(")");
             break;
         }
 	case CSSPrimitiveValue::CSS_RGBCOLOR:
@@ -1376,11 +1376,12 @@ CSSImageValueImpl::CSSImageValueImpl(const DOMString &url, StyleBaseImpl* style)
 	root = root->parent();
     if (root->isCSSStyleSheet())
 	docLoader = static_cast<const CSSStyleSheetImpl*>(root)->docLoader();
-
+    if (docLoader) {
     KUrl fullURL( style->baseURL(), khtml::parseURL(url).string() );
     m_image = docLoader->requestImage( fullURL.url() );
     if(m_image) m_image->ref(this);
 }
+}
 
 CSSImageValueImpl::CSSImageValueImpl()
     : CSSPrimitiveValueImpl(CSS_VAL_NONE)
