@@ -83,11 +83,30 @@ int Battery::chargePercent() const
     return m_device->prop("battery.charge_level.percentage").toInt();
 }
 
+int Battery::capacity() const
+{
+    const qreal lastFull = m_device->prop("battery.charge_level.last_full").toDouble();
+    const qreal designFull = m_device->prop("battery.charge_level.design").toDouble();
+
+    return lastFull / designFull;
+}
+
 bool Battery::isRechargeable() const
 {
     return m_device->prop("battery.is_rechargeable").toBool();
 }
 
+bool Battery::isPowerSupply() const
+{
+    // NOTE Hal doesn't support the is power supply property, so we're assuming that primary
+    // and UPS batteries are power supply and all the others are not
+    if (type() == Solid::Battery::PrimaryBattery || type() == Solid::Battery::UpsBattery) {
+      return true;
+    }
+
+    return false;
+}
+
 Solid::Battery::ChargeState Battery::chargeState() const
 {
     bool charging = m_device->prop("battery.rechargeable.is_charging").toBool();
@@ -114,6 +133,12 @@ void Battery::slotPropertyChanged(const QMap<QString,int> &changes)
         emit chargePercentChanged(chargePercent(), m_device->udi());
     }
 
+    if (changes.contains("battery.charge_level.last_full")
+           || changes.contains("battery.charge_level.design"))
+    {
+        emit capacityChanged(capacity(), m_device->udi());
+    }
+
     if (changes.contains("battery.rechargeable.is_charging")
            || changes.contains("battery.rechargeable.is_discharging"))
     {
